@@ -96,7 +96,7 @@ pub mod config;
 use tracing::instrument;
 pub use error::FluvioError;
 pub use config::FluvioConfig;
-pub use producer::{TopicProducer, RecordKey};
+pub use producer::{TopicProducerConfigBuilder, TopicProducerConfig, TopicProducer, RecordKey};
 
 pub use consumer::{
     PartitionConsumer, ConsumerConfig, MultiplePartitionConsumer, PartitionSelectionStrategy,
